@@ -1,3 +1,4 @@
+import asyncio
 import json
 import logging
 import secrets
@@ -6,9 +7,9 @@ from typing import List
 
 import aiohttp as aiohttp
 
-import const
-from auth import HonAuth
-from device import HonDevice
+from pyhon import const
+from pyhon.auth import HonAuth
+from pyhon.device import HonDevice
 
 _LOGGER = logging.getLogger()
 
@@ -53,9 +54,10 @@ class HonConnection:
                     appliances = (await resp.json())["payload"]["appliances"]
                     for appliance in appliances:
                         device = HonDevice(self, appliance)
-                        await device.load_attributes()
-                        await device.load_commands()
-                        await device.load_statistics()
+                        await asyncio.gather(*[
+                            await device.load_attributes(),
+                            await device.load_commands(),
+                            await device.load_statistics()])
                     self._devices.append(device)
                 except json.JSONDecodeError:
                     _LOGGER.error("No JSON Data after GET: %s", await resp.text())
